<?php

############################################################################
#
# Copyright [2020] [Mihály Héder]
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
############################################################################

require_once "core/fns_db.php";
require_once "core/fns_lang.php";
require_once "core/fns_env.php";
require_once "core/fns_log.php";
require_once "core/fns_misc.php";
require_once "core/fns_email.php";

include "conf.php";

core_log_trace("[core/init_core.php] starting");

#pick up all variables
$GLOBALS['core'] = $core;

if (!empty($core['customcss'])) {
    if (!file_exists($core['customcss'])) {
        log_error("Configured custom CSS:".$core['customcss']." does not exist.");
    } else {
        $GLOBALS['customcss'] = $core['customcss'];
    }
}

core_log_trace("[core/init_core.php] customcss handled");

###########################################################
# get page name and parameters to globals
###########################################################

// only do this on the web
if(php_sapi_name() === 'cli') {
    core_log_trace("[core/init_core.php] not loading pageinfo since we are on cli");
} else {
    core_log_trace("[core/init_core.php] loading pageinfo to globals");
    load_pageinfo_to_globals();
}

###########################################################
# decide actual lang
###########################################################

if (isset($core['languages'])) {
    $GLOBALS['lang'] = $core['languages'][0];
    core_log_trace("[core/init_core.php] default lang loaded:". $GLOBALS['lang']);

    // multiple languages
    if (count($core['languages']) > 1) {
        // check if there is explicit input parameter to change or select lang    
        $lang_selected = filter_input(INPUT_GET, 'lang', FILTER_SANITIZE_ENCODED);
        // incoming lang parameter
        if (!empty($lang_selected)) {
            $GLOBALS['lang'] = $lang_selected;
        }
    }
}
###########################################################
# html elements, default or custom
###########################################################

function make_header($bannertext = null,$bannerimg=null,$metadesc=null) {
    if (file_exists("style/header.php")) {
        include 'style/header.php';
    } else {
        core_log_error("error making header: style/header.php not found!");
    }
}

function make_footer() {
    if (file_exists("style/footer.php")) {
        include 'style/footer.php';
    } else {
        core_log_error("error making footer: style/footer.php not found!");
    }
}

if (file_exists("style/html_elements.php")) {
    require_once 'style/html_elements.php';
}

?>